@@ -25,7 +25,7 @@ from yaclog.changelog import Changelog
 
 
 @click.group()
-@click.option('--path', envvar='YACLOG_PATH', default='CHANGELOG.md', show_default=True,
+@click.option('--path', envvar='YACLOG_PATH', metavar='FILE', default='CHANGELOG.md', show_default=True,
               type=click.Path(dir_okay=False, writable=True, readable=True),
               help='Location of the changelog file.')
 @click.version_option()
@@ -131,8 +131,8 @@ def tag(obj: Changelog, add, tag_name: str, version_name: str):
 
 
 @cli.command(short_help='Add entries to the changelog.')
-@click.option('--bullet', '-b', 'bullets', metavar='text', multiple=True, type=str, help='Add a bullet point.')
-@click.option('--paragraph', '-p', 'paragraphs', metavar='text', multiple=True, type=str, help='Add a paragraph')
+@click.option('--bullet', '-b', 'bullets', metavar='TEXT', multiple=True, type=str, help='Add a bullet point.')
+@click.option('--paragraph', '-p', 'paragraphs', metavar='TEXT', multiple=True, type=str, help='Add a paragraph')
 @click.argument('section_name', metavar='SECTION', type=str, default='', required=False)
 @click.argument('version_name', metavar='VERSION', type=str, default=None, required=False)
 @click.pass_obj
